Simple content management system for Django 1.6+
================================================

``django-pages-cms`` is a simple content management system for Django 1.6+

.. image:: https://travis-ci.org/dlancer/django-pages-cms.svg?branch=master
    :target: https://travis-ci.org/dlancer/django-pages-cms/
    :alt: Build status

.. image:: https://img.shields.io/pypi/v/django-pages-cms.svg
    :target: https://pypi.python.org/pypi/django-pages-cms/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/django-pages-cms.svg
    :target: https://pypi.python.org/pypi/django-pages-cms/
    :alt: Number of PyPI downloads

.. image:: https://img.shields.io/pypi/format/django-pages-cms.svg
    :target: https://pypi.python.org/pypi/django-pages-cms/
    :alt: Download format

.. image:: https://img.shields.io/pypi/l/django-pages-cms.svg
    :target: https://pypi.python.org/pypi/django-pages-cms/
    :alt: License

Requirements
------------

::

    Django>=1.6
    django-appcore>=0.0.5
    django-mptt>=0.7.4
    django-guardian>=1.3
    django-image-cropping>=1.0.1
    django-markitup>=2.2.2
    easy-thumbnails==2.2
    PyYAML>=3.11
    Markdown>=2.6.2

If you use Django<1.7, you should install South==1.0.2

Usage
=====

You may find detailed documentation in the "docs" directory.

